% Display Planck's law
% 22.5.97

c1=1.191044e8;
c2=1.438769e4;

% lambda from 0.1 to 150 microns, interval of 0.01 microns
l=[0.1:0.01:150];

% spectral radiance computation
t=5800; % temperature in kelvin
l5800=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=2000;
l2000=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=1000;
l1000=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=800;
l800=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=300;
l300=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=100;
l100=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
t=50;
l50=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);

% display the results
loglog(l,l5800, l,l2000,l,l1000,l,l800,l,l300,l,l100,l,l50)
AXIS([0.1,150,0.0001,100000000])
title('Planck''s law')
xlabel('wavelength')
ylabel('spectral radiance')
text(1.5,10000000,'7000 K')
% text(1.5,11000000,'5800 K')
% text(1.4,3e+005,'2000 K')
% text(0.38,1.8e+005,'2000 K')
text(0.9,10e+003,'1000 K')
text(2.2,190,'800 K')
text(3,16,'300 K')
text(4.7,0.18,'150 K')
text(10.5,0.0366,'100 K')
text(25,0.002,'50 K')

% hold current graph
hold;

% draw the yellow rectangle of the visible spectrum
x=[0.4,0.4,0.8,0.8];
y=[1e-4,1e8,1e8,1e-4];
patch(x,y,'y')

% display the location of the visible spectrum
text(.11,230,'Locus of')
text(.11,50,'visible')
text(.11,14,'spectrum')
x=[.15,.43];y=[5e+002,5.9859e+003];
line(x,y);

% display results over the rectangle
loglog(l,l5800, 'r',l,l2000,l,l1000,l,l800,l,l300,l,l100,l,l50)
text(0.48,2.5e+005,'2000 K')
text(0.26,2.6e6,'5800 K')

% add grid lines to the current axes
grid

% display line of maximums
t=20;		% 20 K
la=2898/t;
s= (c1*(la^(-5))) / ((exp(c2/(la*t))) - 1);
x(1)=la; y(1)=s;

t=10000;	% 10000 K
la=2898/t;
s= (c1*(la^(-5))) / ((exp(c2/(la*t))) - 1);
x(2)=la; y(2)=s;
line(x,y)

% display text about the line of max
text(12,3.4e5,'Locus of maxima')
x=[2.43,11.32];y=[2.1886e+004,3.1730e+005];
line(x,y);

% spectral radiance computation at 7000 K
t=7000;
l7000=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
loglog(l,l7000,'y');

% spectral radiance computation at 150 K
t=150;
l150=(c1.*(l.^(-5))) ./ ((exp(c2./(l.*t))) - 1);
loglog(l,l150,'y');

% add the file name
text(15, 1.1e-005,'[Planck.m]')

% gets the x and y coordinates on the plot
% [X,Y] = ginput(1)