%**********
% kernel.m
%
% MATLAB M-File for image enhancement through the
% use of a kernel of values, eq. (5.16). Return the
% enhanced image. Images are of unsigned characters type.
%
% Example of use:
%  mat1=kernel(mat,2,array);
%
% with array defined previously as for a 2x2
% Roberts gradient: array = [1 0; 0 -1];
%
% Date : 17.05.2000
%
% Last modification: 02.06.2000
%
%**********

function mat1 = kernel(mat,ascale,array)


% ***** Size of matrix and initialization of mat1
[mrow, mcol]=size(mat);
mat1=zeros(mrow,mcol);


% ***** Size of array
[arow, acol]=size(array);
array=ascale.*array;

% ***** Number of elements around (i,j)
frow=floor(arow/2);	% round towards smallest
fcol=floor(acol/2);	% nearest integer

crow=ceil(arow/2);	% round towards largest
ccol=ceil(acol/2);	% nearest integer


% ***** Image enhancement
for i=1:mrow,
	for j=1:mcol,


% ***** Left side (with (i,j))
if j>fcol	% general case
	l=ccol;
else
	l=j;	% sides and corners case
end


% ***** Right side
if (mcol-j)>fcol	% general case
	r=fcol;
else
	r=mcol-j;	% sides and corners case
end

% ***** Up side (with (i,j))
if i>frow	% general case
	u=crow;
else
	u=i;	% sides and corners case
end

% ***** Down side
if (mrow-i)>frow	% general case
	d=frow;
else
	d=mrow-i;	% sides and corners case
end


% ***** Kernel of interest
ker=array(1:u+d,1:l+r).*mat(i-u+1:i+d,j-l+1:j+r);


% ***** Attribution of new value to (i,j)
mat1(i,j)=sum(ker(:));	% sum all elements of ker

	end
end

%mat1=mat_fl_to_uc(mat1);

% ***** Display the image
colormap(gray);
imagesc(mat1);
colorbar;
