%**********
% poin_pro.m
%
% MATLAB M-File for point processing routine
% with parameters a and b. Return the processed
% image, based on figure 5.18. Images are of
% unsigned characters type.
%
% Adjustable parameter is:
%  Maxcolor: maximum value of a pixel
%			(255 if on 8 bits)
%
% Example of use:
%  mat1=poin_pro(mat,10,25);
%
% with b=Maxcolor, a becomes the threshold, eq.(5.15).
%
% Date : 16.05.2000
%
% Last modification: 02.06.2000
%
%**********

function mat1 = pp2(mat,a,b)


Maxcolor=255;

% ***** Size of matrix and initialization of mat1
[mrow, mcol]=size(mat);
mat1=zeros(mrow,mcol);

% ***** Values needed for point processing
m1=b/a;
m2=(Maxcolor-b)/(Maxcolor-a);
c=b-m2*a;


% ***** Point processing

sm=find(mat<=a);	% find all data smaller or equal to a
gr=find(mat>a);	% find all data greater than a

if b~=Maxcolor
	mat1(sm)=m1.*mat(sm);
else	% a becomes a threshold
	mat1(sm)=0;
end

% values given by a line through
% (a,b) and (Maxcolor, Maxcolor)
mat1(gr)=m2.*mat(gr)+c;


% ***** Display the image
colormap(gray);
imagesc(mat1);
colorbar;
