%**********
% smooth.m
%
% MATLAB M-File to smooth out noise from image
% mat with parameter B (for Gaussian width),
% based on eq.(5.31). Images are of unsigned
% characters type.
% Adjustable parameter is:
%  Nbpasse: number of iterations for smoothing
%
% Example of use:
%  mat1=smooth(mat,4);
%
% Date : 25.05.2000
%
% Last modification: 02.06.2000
%
%**********

function  mat1=smooth(mat,B)


% ***** Size of matrix and initialization
[mrow, mcol]=size(mat);
mat0=zeros(mrow,mcol);
mat1=zeros(mrow,mcol);
Nbpasse=2;


% ***** Initialization of the Gaussian
imax=7*B+1;
i=[1:imax];	% array with values needed for i
expo=exp((-0.5)*(((i-imax/2)./B).^2));

% ***** Compute the Gaussian, eq.(5.29) and (5.30)
f=expo./sum(expo);


% ***** Processing on rows
smoothed=zeros(mrow,mcol);	% vector of mcol zeros, initialixaton of smoothed


for it=1:Nbpasse	% for all iterations

	for omega=1:mcol	% for all elements of the row
		value=smoothed(:,omega);

		for i=1:imax	% for all elements of the gaussian
	       	index = omega - round(imax/2) + i;

      if index < 1
			value = value + (mat(:,1)-smoothed(:,1)).*f(i);
		elseif index > mcol
			value = value + (mat(:,mcol)-smoothed(:,mcol)).*f(i);
		else
			value = value + (mat(:,index)-smoothed(:,index)).*f(i);
		end % if

		end % for imax
      
	mat0(:,omega)=value;
	end % for omega
     
end % for Nbpasse


% ***** Processing on columns
smoothed=zeros(mrow,mcol);	% vector of mcol zeros, initialixaton of smoothed


for it=1:Nbpasse	% for all iterations

	for omega=1:mrow	% for all elements of the row
		value=smoothed(omega,:);

		for i=1:imax	% for all elements of the gaussian
	       	index = omega - round(imax/2) + i;

      if index < 1
			value = value + (mat0(1,:)-smoothed(1,:)).*f(i);
		elseif index > mrow
			value = value + (mat0(mrow,:)-smoothed(mrow,:)).*f(i);
		else
			value = value + (mat0(index,:)-smoothed(index,:)).*f(i);
		end % if

		end % for imax
      
	mat1(omega,:)=value;
	end % for omega
     
end % for Nbpasse


%mat1=mat_fl_to_uc(mat1);

% ***** Display the image
colormap(gray);
imagesc(mat1);
colorbar;
